@@ -32,6 +32,7 @@ struct _ServiceRole
 static ServiceRole services[] = {
 	/* keep this list alphabetically sorted! otherwise bsearch will be funny */
 	{ "acct",                   GST_ROLE_SYSTEM_MONITORING },
+	{ "acpi-support",           GST_ROLE_POWER_MANAGEMENT },
 	{ "acpid",                  GST_ROLE_POWER_MANAGEMENT },
 	{ "alsa",                   GST_ROLE_AUDIO_MANAGEMENT },
 	{ "alsasound",              GST_ROLE_AUDIO_MANAGEMENT },
@@ -49,6 +50,7 @@ static ServiceRole services[] = {
 	{ "apt-index-watcher",      GST_ROLE_PACKAGE_INDEX_MONITORING },
 	{ "atd",                    GST_ROLE_COMMAND_SCHEDULER },
 	{ "atftpd",                 GST_ROLE_FILE_SERVER_FTP },
+	{ "atop",                   GST_ROLE_SYSTEM_MONITORING },
 	{ "aumix",                  GST_ROLE_AUDIO_MANAGEMENT },
 	{ "autofs",                 GST_ROLE_AUTOMOUNTER },
 	{ "avahi-daemon",           GST_ROLE_RENDEZVOUS },
@@ -76,15 +78,18 @@ static ServiceRole services[] = {
 	{ "cupsys",                 GST_ROLE_PRINTER_SERVICE },
 	{ "dbus",                   GST_ROLE_DBUS },
 	{ "ddclient",               GST_ROLE_DYNAMIC_DNS_SERVICE },
+	{ "dhcdbd",                 GST_ROLE_NETWORK },
 	{ "dhcp3-server",           GST_ROLE_DHCP_SERVER },
 	{ "dhis-client",            GST_ROLE_DYNAMIC_DNS_SERVICE },
 	{ "dictd",                  GST_ROLE_DICTIONARY_SERVER },
+	{ "dnsmasq",                GST_ROLE_DNS },
 	{ "dovecot",                GST_ROLE_MTA },
 	{ "eagle-usb",              GST_ROLE_EAGLE_USB_MODEMS_MANAGEMENT },
 	{ "etc-setserial",          GST_ROLE_SERIAL_PORTS_MANAGEMENT },
 	{ "evms",                   GST_ROLE_LVM_MANAGEMENT },
 	{ "exim",                   GST_ROLE_MTA },
 	{ "exim4",                  GST_ROLE_MTA },
+	{ "fancontrol",             GST_ROLE_POWER_MANAGEMENT },
 	{ "fcron",                  GST_ROLE_COMMAND_SCHEDULER },
 	{ "festival",               GST_ROLE_SPEECH_SYNTHESIS },
 	{ "fetchmail",              GST_ROLE_MAIL_FETCHER },
@@ -106,11 +111,15 @@ static ServiceRole services[] = {
 	{ "irda-setup",             GST_ROLE_INFRARED_MANAGEMENT },
 	{ "irda-utils",             GST_ROLE_INFRARED_MANAGEMENT },
 	{ "isdnutils",              GST_ROLE_ISDN_MANAGEMENT },
+	{ "jackd",                  GST_ROLE_AUDIO_MANAGEMENT },
 	{ "kde-guidance",           GST_ROLE_SYSTEM_CONFIGURATION_MANAGEMENT },
 	{ "kdm",                    GST_ROLE_DISPLAY_MANAGER },
+	{ "kdump",                  GST_ROLE_AUTOMATED_CRASH_REPORTS_MANAGEMENT },
 	{ "keepalived",             GST_ROLE_CLUSTER_MANAGEMENT },
+	{ "kerneloops",             GST_ROLE_AUTOMATED_CRASH_REPORTS_MANAGEMENT },
 	{ "klogd",                  GST_ROLE_SYSTEM_LOGGER },
 	{ "landscape-client",       GST_ROLE_SYSTEM_MONITORING },
+	{ "laptop-mode",            GST_ROLE_POWER_MANAGEMENT },
 	{ "lighttpd",               GST_ROLE_WEB_SERVER },
 	{ "lm-sensors",             GST_ROLE_HARDWARE_MONITORING },
 	{ "lpd",                    GST_ROLE_PRINTER_SERVICE },
@@ -149,7 +158,9 @@ static ServiceRole services[] = {
 	{ "ocfs2-tools",            GST_ROLE_CLUSTER_MANAGEMENT },
 	{ "oem-config",             GST_ROLE_OEM_CONFIGURATION_MANAGEMENT },
 	{ "oftpd",                  GST_ROLE_FILE_SERVER_FTP },
+	{ "ondemand",               GST_ROLE_CPUFREQ_MANAGEMENT },
 	{ "openais",                GST_ROLE_CLUSTER_MANAGEMENT },
+	{ "openvpn",                GST_ROLE_VPN_SERVER },
 	{ "pbbuttonsd",             GST_ROLE_HOTKEYS_MANAGEMENT },
 	{ "portmap",                GST_ROLE_RPC_MAPPER },
 	{ "postfix",                GST_ROLE_MTA },
@@ -163,8 +174,11 @@ static ServiceRole services[] = {
 	{ "postgresql-8.5",         GST_ROLE_DATABASE_SERVER },
 	{ "postgresql-9.0",         GST_ROLE_DATABASE_SERVER },
 	{ "powernowd",              GST_ROLE_CPUFREQ_MANAGEMENT },
+	{ "powernowd.early",        GST_ROLE_CPUFREQ_MANAGEMENT },
+	{ "pppd-dns",               GST_ROLE_NETWORK },
 	{ "pptpd",                  GST_ROLE_VPN_SERVER },
 	{ "proftpd",                GST_ROLE_FILE_SERVER_FTP },
+	{ "pulseaudio",             GST_ROLE_AUDIO_MANAGEMENT },
 	{ "pure-ftpd",              GST_ROLE_FILE_SERVER_FTP },
 	{ "rc-inetd",               GST_ROLE_NETWORK },
 	{ "qmail",                  GST_ROLE_MTA },
@@ -189,6 +203,7 @@ static ServiceRole services[] = {
 	{ "smb",                    GST_ROLE_FILE_SERVER_SMB },
 	{ "snmpd",                  GST_ROLE_SNMP_SERVER },
 	{ "spamassassin",           GST_ROLE_SPAM_FILTER },
+	{ "speech-dispatcher",      GST_ROLE_SPEECH_SYNTHESIS },
 	{ "squid",                  GST_ROLE_PROXY_CACHE },
 	{ "ssh",                    GST_ROLE_SECURE_SHELL_SERVER },
 	{ "sshd",                   GST_ROLE_SECURE_SHELL_SERVER },
@@ -196,7 +211,10 @@ static ServiceRole services[] = {
 	{ "syslog",                 GST_ROLE_SYSTEM_LOGGER },
 	{ "syslog-ng",              GST_ROLE_SYSTEM_LOGGER },
 	{ "tftpd-hpa",              GST_ROLE_FILE_SERVER_TFTP },
+	{ "ufw",                    GST_ROLE_FIREWALL_MANAGEMENT },
 	{ "vcron",                  GST_ROLE_COMMAND_SCHEDULER },
+	{ "virtualbox",             GST_ROLE_VIRTUAL_MACHINE_MANAGEMENT },
+	{ "virtualbox-ose",         GST_ROLE_VIRTUAL_MACHINE_MANAGEMENT },
 	{ "vixie-cron",             GST_ROLE_COMMAND_SCHEDULER },
 	{ "vmware-player",          GST_ROLE_VIRTUAL_MACHINE_MANAGEMENT },
 	{ "vsftpd",                 GST_ROLE_FILE_SERVER_FTP },
@@ -209,6 +227,7 @@ static ServiceRole services[] = {
 	{ "xinetd",                 GST_ROLE_NETWORK },
 	{ "zmailer",                GST_ROLE_MTA },
 	{ "zope3",                  GST_ROLE_APPLICATION_SERVER },
+	{ "network-manager",        GST_ROLE_NETWORK },
 	{ "NetworkManager",         GST_ROLE_NETWORK },
 };
 
