@@ -56,6 +56,12 @@ show_settings (void)
 			    COL_OBJECT, &service,
 			    -1);
 
+	/* Don't try to commit if not allowed */
+	if (!gst_tool_authenticate (tool, OOBS_OBJECT (service))) {
+		g_object_unref (service);
+		return;
+	}
+
 	title = g_strdup_printf (_("Settings for service \"%s\""),
 				 oobs_service_get_name (service));
 
@@ -75,7 +81,7 @@ show_settings (void)
 
 	if (response != GTK_RESPONSE_NONE) {
 		service_settings_table_save (service);
-		gst_tool_commit (tool, GST_SERVICES_TOOL (tool)->services_config);
+		gst_tool_commit (tool, OOBS_OBJECT (service));
 	}
 
 	g_object_unref (service);
@@ -154,6 +160,12 @@ on_service_toggled (GtkCellRenderer *renderer, gchar *path_str, gpointer data)
 			    COL_DANGEROUS, &dangerous,
 			    -1);
 
+	/* Don't try to commit if not allowed */
+	if (!gst_tool_authenticate (tool, OOBS_OBJECT (service))) {
+		g_object_unref (service);
+		return;
+	}
+
 	if (new_value || !dangerous || show_warning_dialog (tool, service)) {
 		OobsServicesRunlevel *rl;
 		
@@ -162,15 +174,17 @@ on_service_toggled (GtkCellRenderer *renderer, gchar *path_str, gpointer data)
 							 (new_value) ? OOBS_SERVICE_START : OOBS_SERVICE_STOP,
 							 /* Keep previous priority, see how liboobs handles this */
 							 0);
-		gst_tool_commit (tool, GST_SERVICES_TOOL (tool)->services_config);
+		if (gst_tool_commit (tool, OOBS_OBJECT (service)) != OOBS_RESULT_OK)
+			new_value = !new_value;
 
 		gtk_list_store_set (GTK_LIST_STORE (model),
-				    &iter,
-				    COL_ACTIVE, new_value,
-				    -1);
+		                    &iter,
+		                    COL_ACTIVE, new_value,
+		                    -1);
 	}
 
 	gtk_tree_path_free (path);
+	g_object_unref (service);
 }
 
 void
